:mod:`lck.cache.memoization`
============================

.. automodule:: lck.cache.memoization

.. note::

  Instead of importing the whole structure, a recommended shortcut is available.
  Use ``from lck.cache import memoize``.

Functions
----------

.. autofunction:: memoize
